pub fn value_to_lua(lua: &Lua, v: &Value) -> Result<Value>Expand description
Converts a kui_core::Value to a Lua value: the inverse of
lua_to_value, used to hand event payloads and slot params to a script.
pub fn value_to_lua(lua: &Lua, v: &Value) -> Result<Value>Converts a kui_core::Value to a Lua value: the inverse of
lua_to_value, used to hand event payloads and slot params to a script.